<table>
    <td style="white-space: nowrap;">Last</td><td style="white-space: nowrap;">{{ last_appt }}</td>
  </tr>
  <tr>
    <td style="white-space: nowrap;">Next</td><td style="white-space: nowrap;">{{ next_appt }}</td>
  </tr>
</table>
