# Generated by Django 4.1.2 on 2022-11-21 22:44

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0005_historicalpatientcall_alt_contact_number_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalpatientcall",
            name="willing_to_attend",
        ),
        migrations.RemoveField(
            model_name="patientcall",
            name="willing_to_attend",
        ),
        migrations.AddField(
            model_name="historicalpatientcall",
            name="catchment_area",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_sure", "Not sure"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Does the participant still reside within the catchment area",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientcall",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_sure", "Not sure"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Is the participant known to be alive",
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="catchment_area",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_sure", "Not sure"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Does the participant still reside within the catchment area",
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("not_sure", "Not sure"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Is the participant known to be alive",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientcall",
            name="attend_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="When can the patient next attend"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientcall",
            name="call_again",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="May we call again?",
            ),
        ),
        migrations.AlterField(
            model_name="patientcall",
            name="attend_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="When can the patient next attend"
            ),
        ),
        migrations.AlterField(
            model_name="patientcall",
            name="call_again",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="May we call again?",
            ),
        ),
    ]
