# Generated by Django 4.1.7 on 2023-04-20 15:58

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0034_clinicalreviewbaseline_protocol_incident_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="drugrefilldm",
            name="return_in_days",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In how many days has the patient been asked to return to clinic for a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhiv",
            name="return_in_days",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In how many days has the patient been asked to return to clinic for a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhtn",
            name="return_in_days",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In how many days has the patient been asked to return to clinic for a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefilldm",
            name="return_in_days",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In how many days has the patient been asked to return to clinic for a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="return_in_days",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In how many days has the patient been asked to return to clinic for a drug refill?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhtn",
            name="return_in_days",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(180),
                ],
                verbose_name="In how many days has the patient been asked to return to clinic for a drug refill?",
            ),
        ),
    ]
