# Generated by Django 4.2.3 on 2023-07-26 18:24

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0054_alter_healthtalklog_unique_together"),
    ]

    operations = [
        migrations.DeleteModel(
            name="IdentifierFormat",
        ),
    ]
