# Generated by Django 4.2.3 on 2023-07-26 13:14

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        # ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_lists", "0006_consentrefusalreasons_screeningrefusalreasons_and_more"),
        ("intecomm_screening", "0046_alter_historicalpatientlog_legal_name_and_more"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="healthtalklog",
            unique_together=set(),
        ),
        migrations.RenameField(
            model_name="historicalhealthtalklog",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
        migrations.RenameField(
            model_name="healthtalklog",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
        migrations.RenameField(
            model_name="idenfifierformat",
            old_name="health_facility",
            new_name="old_health_facility",
        ),
    ]
