# Generated by Django 4.2.9 on 2024-01-30 01:00

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0138_alter_bloodresultsfbc_site_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsins",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="glucose_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="dmreview",
            name="glucose_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="glucose_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="glucose_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_fasting_duration_minutes",
            field=models.IntegerField(
                blank=True, help_text="system calculated value", null=True
            ),
        ),
    ]
