# Generated by Django 4.1.7 on 2023-05-02 22:52

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0026_alter_historicalpatientlog_filing_identifier_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientlog",
            name="printed",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="printed",
            field=models.BooleanField(default=False),
        ),
    ]
