# Generated by Django 4.2.11 on 2024-05-02 00:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0182_dmcurrentconditions"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmcurrentconditions",
            name="dm",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="dmcurrentconditions",
            name="dm_dx_days",
            field=models.IntegerField(
                default=None, help_text="Number of days relative to baseline", null=True
            ),
        ),
        migrations.AlterField(
            model_name="dmcurrentconditions",
            name="hiv",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="dmcurrentconditions",
            name="hiv_dx_days",
            field=models.IntegerField(
                default=None, help_text="Number of days relative to baseline", null=True
            ),
        ),
        migrations.AlterField(
            model_name="dmcurrentconditions",
            name="htn",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="dmcurrentconditions",
            name="htn_dx_days",
            field=models.IntegerField(
                default=None, help_text="Number of days relative to baseline", null=True
            ),
        ),
    ]
