# Generated by Django 4.1.2 on 2022-12-06 23:04

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0005_alter_historicalsocialharms_coworkers_impact_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="healtheconomics",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Health Economics",
                "verbose_name_plural": "Health Economics",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalhealtheconomics",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Health Economics",
                "verbose_name_plural": "historical Health Economics",
            },
        ),
    ]
