# Generated by Django 4.2.1 on 2023-07-07 19:32

from django.db import migrations
import edc_action_item.managers
import edc_adverse_event.model_mixins.death_report.death_report_tmg_model_mixin


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_ae",
            "0004_alter_aefollowup_options_alter_aeinitial_options_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="aefollowup",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="aeinitial",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="aesusar",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="aetmg",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="deathreport",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="deathreporttmg",
            managers=[
                (
                    "objects",
                    edc_adverse_event.model_mixins.death_report.death_report_tmg_model_mixin.DeathReportTmgManager(),
                ),
                (
                    "on_site",
                    edc_adverse_event.model_mixins.death_report.death_report_tmg_model_mixin.DeathReportTmgSiteManager(),
                ),
            ],
        ),
    ]
