# Generated by Django 4.1.7 on 2023-04-19 14:01

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0031_alter_clinicalreviewbaseline_dm_dx_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnextappointment",
            name="best_visit_code",
            field=models.CharField(
                choices=[
                    ("100", "100"),
                    ("1010", "1010"),
                    ("1020", "1020"),
                    ("1030", "1030"),
                    ("1040", "1040"),
                    ("1050", "1050"),
                    ("1060", "1060"),
                    ("1070", "1070"),
                    ("1080", "1080"),
                    ("1090", "1090"),
                    ("1100", "1100"),
                    ("1110", "1110"),
                    ("1120", "1120"),
                ],
                help_text=(
                    "Click save to let the EDC suggest. Once selected, previous visits will be flagged as not required.",
                ),
                max_length=15,
                null=True,
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="best_visit_code",
            field=models.CharField(
                choices=[
                    ("100", "100"),
                    ("1010", "1010"),
                    ("1020", "1020"),
                    ("1030", "1030"),
                    ("1040", "1040"),
                    ("1050", "1050"),
                    ("1060", "1060"),
                    ("1070", "1070"),
                    ("1080", "1080"),
                    ("1090", "1090"),
                    ("1100", "1100"),
                    ("1110", "1110"),
                    ("1120", "1120"),
                ],
                help_text=(
                    "Click save to let the EDC suggest. Once selected, previous visits will be flagged as not required.",
                ),
                max_length=15,
                null=True,
                verbose_name="Which study visit code is closest to this appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started medicines for diabetes",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for diabetes",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was medicines for diabetes start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="Yes",
                max_length=15,
                verbose_name="Has the patient started medicines for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init_calculated_date",
            field=models.DateField(
                editable=False,
                help_text="Calculated based on response to `rx_init_ago`",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Estimated date started medicines for diabetes",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for diabetes",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="rx_init_date_is_estimated",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="N/A",
                editable=False,
                max_length=15,
                verbose_name="Was medicines for diabetes start date estimated?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("=", "="), (">", ">"), ("<", "<"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="historicalviralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("=", "="), (">", ">"), ("<", "<"), ("N/A", "Not applicable")],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started antiretroviral therapy (ART)",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("=", "="), (">", ">"), ("<", "<"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="rx_init_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date started medicines for hypertension",
            ),
        ),
        migrations.AlterField(
            model_name="viralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("=", "="), (">", ">"), ("<", "<"), ("N/A", "Not applicable")],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
    ]
