# Generated by Django 4.1.7 on 2023-04-04 00:41

import edc_model.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0019_remove_historicalhtninitialreview_med_start_date_estimated_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalhtninitialreview",
            old_name="managed_by",
            new_name="managed_by_old",
        ),
        migrations.RenameField(
            model_name="htninitialreview",
            old_name="managed_by",
            new_name="managed_by_old",
        ),
        migrations.RemoveField(
            model_name="historicalhtninitialreview",
            name="med_start_date",
        ),
        migrations.RemoveField(
            model_name="htninitialreview",
            name="med_start_date",
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="dx_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date patient diagnosed",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="dx_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date patient diagnosed",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="dx_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date patient diagnosed",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="dx_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date patient diagnosed",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhtninitialreview",
            name="med_start_estimated_date",
            field=models.DateField(
                editable=False,
                help_text="auto completed",
                null=True,
                verbose_name="Estimated medication start date",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="dx_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date patient diagnosed",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="dx_date",
            field=models.DateField(
                blank=True,
                help_text="If possible, provide the exact date here instead of estimating.",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date patient diagnosed",
            ),
        ),
        migrations.AlterField(
            model_name="htninitialreview",
            name="med_start_estimated_date",
            field=models.DateField(
                editable=False,
                help_text="auto completed",
                null=True,
                verbose_name="Estimated medication start date",
            ),
        ),
    ]
