# Generated by Django 4.2.11 on 2024-05-31 14:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("intecomm_subject", "0184_rename_dmcurrentconditions_currentconditions_and_more"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="CurrentConditions",
            new_name="Diagnoses",
        ),
        migrations.RenameIndex(
            model_name="diagnoses",
            new_name="intecomm_su_modifie_b03a1f_idx",
            old_name="intecomm_su_modifie_490726_idx",
        ),
        migrations.RenameIndex(
            model_name="diagnoses",
            new_name="intecomm_su_user_mo_24138d_idx",
            old_name="intecomm_su_user_mo_15c1bf_idx",
        ),
    ]
