# Generated by Django 4.2.3 on 2023-08-03 16:18

from django.db import migrations
import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0087_alter_healtheconomicspatient_pat_citizen_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicspatient",
            name="pat_employment_type_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=100,
                null=True,
                verbose_name="If OTHER type of employment, specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicspatient",
            name="pat_employment_type_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=100,
                null=True,
                verbose_name="If OTHER type of employment, specify ...",
            ),
        ),
    ]
