# Generated by Django 5.0.4 on 2024-04-10 17:30

import django.core.validators
import edc_model_fields.fields.custom_django_fields
import edc_model_fields.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "intecomm_subject",
            "0153_rename_visit_duration_careseekinga_care_visit_duration_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="careseekinga",
            name="missed_activities_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FMEDOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekinga",
            name="missed_activities_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FMEDOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FMED1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="tests_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FTESTCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much did you spend on these tests?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                metadata="FOUTMEDNO1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FMED1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="tests_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FTESTCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much did you spend on these tests?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                metadata="FOUTMEDNO1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
    ]
