# Generated by Django 4.1.7 on 2023-04-03 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0018_remove_historicalhivinitialreview_vl_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhtninitialreview",
            name="med_start_date_estimated",
        ),
        migrations.RemoveField(
            model_name="htninitialreview",
            name="med_start_date_estimated",
        ),
        migrations.AddField(
            model_name="historicalhtninitialreview",
            name="med_start_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If the patient is taking medicines for hypertension, on which date did they start taking these?",
            ),
        ),
        migrations.AddField(
            model_name="htninitialreview",
            name="med_start_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If the patient is taking medicines for hypertension, on which date did they start taking these?",
            ),
        ),
    ]
