# Generated by Django 4.2.1 on 2023-05-24 17:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0048_alter_healtheconomicsincome_external_remittance_currency_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status",
            field=models.CharField(
                choices=[
                    ("1", "Very good"),
                    ("2", "Good"),
                    ("3", "Moderate"),
                    ("4", "Bad"),
                    ("5", "Very bad"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="Would you say your household's financial situation is?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household’s financial situation compared with others in your community?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Income from wages, salary from job",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="financial_status",
            field=models.CharField(
                choices=[
                    ("1", "Very good"),
                    ("2", "Good"),
                    ("3", "Moderate"),
                    ("4", "Bad"),
                    ("5", "Very bad"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="Would you say your household's financial situation is?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household’s financial situation compared with others in your community?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Income from wages, salary from job",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
    ]
