# Generated by Django 4.2.3 on 2023-08-03 15:57

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0085_alter_healtheconomicsassets_external_wall_material_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomicshouseholdhead",
            old_name="hoh_employment",
            new_name="hoh_employment_status",
        ),
        migrations.RenameField(
            model_name="healtheconomicspatient",
            old_name="pat_employment",
            new_name="pat_employment_status",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicshouseholdhead",
            old_name="hoh_employment",
            new_name="hoh_employment_status",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicspatient",
            old_name="pat_employment",
            new_name="pat_employment_status",
        ),
    ]
