# Generated by Django 4.2.3 on 2023-08-10 03:23

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0098_alter_healtheconomicshouseholdhead_hoh_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="healtheconomicspatient",
            name="pat_citizen",
        ),
        migrations.RemoveField(
            model_name="historicalhealtheconomicspatient",
            name="pat_citizen",
        ),
    ]
