# Generated by Django 4.1.7 on 2023-03-31 18:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0016_remove_clinicalreview_reason_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="dmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalviralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="viralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
    ]
