# Generated by Django 4.2.11 on 2024-06-20 19:38

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0187_alter_dmreview_glucose_fasting_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Diagnoses",
        ),
    ]
