# Generated by Django 4.2.5 on 2023-10-05 23:36

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        # ("edc_next_appointment", "0002_infosources_extra_value"),
        ("edc_appointment", "0046_infosources"),
        ("intecomm_subject", "0119_auto_20231006_0220"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalnextappointment",
            old_name="info_source",
            new_name="info_source_old",
        ),
        migrations.RenameField(
            model_name="nextappointment",
            old_name="info_source",
            new_name="info_source_old",
        ),
    ]
