# Generated by Django 4.1.2 on 2022-11-20 21:08

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("intecomm_lists", "0001_initial"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_screening", "0001_initial"),
        ("intecomm_group", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="patientgroupmeeting",
            name="patients",
            field=models.ManyToManyField(
                to="intecomm_screening.patientlog", verbose_name="Patients"
            ),
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="community_care_location",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_group.communitycarelocation",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="patient_group",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_group.patientgroup",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="patients",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_screening.patientlog",
                verbose_name="Membership",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="history_user",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AddField(
            model_name="communitycarelocation",
            name="location_type",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_lists.locationtypes",
            ),
        ),
        migrations.AddField(
            model_name="communitycarelocation",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]
