# Generated by Django 4.2.1 on 2023-05-24 03:03

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0047_healtheconomicsassets_cooking_fuel_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_currency",
            field=models.CharField(
                blank=True,
                choices=[
                    ("USD", "USD"),
                    ("GBP", "GBP"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Dont' know"),
                ],
                max_length=50,
                null=True,
                verbose_name="In what currency do you receive remittances?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Do you have additional sources of income not included above?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_other",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If YES additional sources, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_additional_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_additional_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_currency",
            field=models.CharField(
                blank=True,
                choices=[
                    ("USD", "USD"),
                    ("GBP", "GBP"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Dont' know"),
                ],
                max_length=50,
                null=True,
                verbose_name="In what currency do you receive remittances?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Do you have additional sources of income not included above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_other",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If YES additional sources, specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Estimate the total amount of income from this source for the household over the time period indicated above",
                null=True,
                verbose_name="Estimate the total amount",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "Weekly income"),
                    ("monthly", "Monthly income"),
                    ("yearly", "Yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Estimate the total amount of income from this source for the household over the last ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_additional_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_additional_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="About how much is this worth in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_value_known",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Use cash equivalent in local currency",
                max_length=25,
                verbose_name="Do you know about how much is this worth in total?",
            ),
        ),
    ]
