# Generated by Django 5.0.4 on 2024-04-16 11:24

import intecomm_subject.models.fields.expense_field
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0171_alter_careseekinga_travel_time_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINCOST1",
                verbose_name="How much was spent in total on your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINFOODCOST1",
                verbose_name="How much was spent on this food and drink?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINCOST1",
                verbose_name="How much was spent in total on your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FINFOODCOST1",
                verbose_name="How much was spent on this food and drink?",
            ),
        ),
    ]
