# Generated by Django 4.2.7 on 2023-12-05 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0017_alter_subjectconsent_options_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="subjectconsent",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_co_modifie_45691e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectconsent",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_co_user_mo_5935e6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectreconsent",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_co_modifie_fddd38_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectreconsent",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_co_user_mo_4da839_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=("subject_identifier", "version"),
                name="intecomm_consent_subjectconsent_subj_ver_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=("legal_name", "initials", "version"),
                name="intecomm_consent_subjectconsent_legal_name_uniq",
            ),
        ),
    ]
