# Generated by Django 5.0.4 on 2024-04-15 17:45

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations

import intecomm_subject.models.fields.duration_field
import intecomm_subject.models.fields.expense_field
import intecomm_subject.models.fields.income_field


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_subject", "0169_alter_bloodresultsins_fasting_duration_str_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="careseekinga",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="careseekingb",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="careseekingb",
            name="care_visit_lost_income",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekinga",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekingb",
            name="accompany_lost_income",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekingb",
            name="care_visit_lost_income",
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FACMP1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(15),
                ],
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during today’s visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FFACTIME1",
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="care_visit_lost_income",
            field=intecomm_subject.models.fields.income_field.IncomeField(
                blank=True,
                metadata="FPAID1",
                null=True,
                verbose_name="How much would you have made in cash or in-kind for a day’s work?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFOODCOST1",
                null=True,
                verbose_name="Thinking about yourself and anyone that accompanied you, how much did you have to pay for food, drink or other refreshments during your travel or during your visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_dm",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTDM1",
                verbose_name="How much was spent on Diabetes medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_hiv",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHIV1", verbose_name="How much was spent on HIV medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_htn",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHTN1",
                verbose_name="How much was spent on Hypertension medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_other",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTOTHER1",
                verbose_name="How much was spent on OTHER medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FACTIVITY1",
                verbose_name="If you were not attending the visit today, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="travel_time",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FTRATIME1", verbose_name="How long did it take you to reach here?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="wait_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWAITIME1", verbose_name="How much time did you spend waiting?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="with_hcw_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWORKTIME1",
                verbose_name="How much time did you spend during the consultation (i.e. time spent with the healthcareworker)?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                metadata="FOUTACMP1",
                to="intecomm_lists.accompanied",
                verbose_name="Who accompanied you to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="care_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTIME1",
                verbose_name="Roughly how much time did you spend during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="food_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFOODCOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, did you have to pay for food, drink or other refreshments during your travel or during your last/most recent visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="ill_month",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                metadata="FILLMONTH1",
                verbose_name="Other than today’s visit, and thinking about the past 3 months, did you need to make any routine visits or were you ill or in need of healthcare at any point for HIV, Hypertension, Diabetes or anything related to you having these conditions?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDNO1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_prescribed",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FOUTMED1",
                verbose_name="Were you prescribed any medicines during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                blank=True,
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Money received from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Money received from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FOUTSOURCE",
                related_name="%(app_label)s_money_sources_related",
                related_query_name="%(app_label)s_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="Thinking about the expenses you have reported in the past 3 months, and excluding today’s visit, what were the source(s) of payment for all these expenses?  ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="no_seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("not_necessary", "Did not think it was necessary "),
                    ("recovered", "Recovered before I could go "),
                    (
                        "home_remedy",
                        "Home remedy given by family member, relatives, neighbours ",
                    ),
                    ("too_expensive", "Too expensive "),
                    ("no_time", "Wanted to but could not find time"),
                    ("no_transport", "There was no one to take me"),
                    ("facility_too_far", "The health facility is too far/ not easy to reach "),
                    ("hcw_unavailable", "Health care practitioner mostly unavailable "),
                    ("med_problems", "Taking medicines caused problems"),
                    (
                        "hcw_confusing",
                        "Do not understand what the healthcare practitioner says ",
                    ),
                    ("hcw_incompetent", "Practitioner is not competent in their work "),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If NO, STOP and SAVE form",
                max_length=25,
                metadata="FNOSEEK1",
                verbose_name="If no, why did you not make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you make the visit, seek advice or treatment (public facility, local pharmacy, traditional doctor etc)?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("comm_health_centre", "Community health centre/health post"),
                    ("gov_dispensary", "Government dispensary"),
                    ("phc", "Primary health care center (PHC)"),
                    ("private_clinic", "Private clinic"),
                    ("ngo", "NGO clinic"),
                    ("public_hospital", "Public Hospital"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("hcw_home", "Any healthcare practitioner’s home"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKFAC1",
                verbose_name="If yes, where did you make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_requested",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="for example, blood pressure, viral load, glucose etc.",
                max_length=25,
                metadata="FOUTTEST1",
                verbose_name="Did the healthcare worker request for any tests to be done during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTRACOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTRATIME1", verbose_name="How long did it take you to get there?"
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="travel_method",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                metadata="FOUTTRA1",
                to="intecomm_lists.travelmethods",
                verbose_name="Thinking about your last/most recent visit, how did you travel to the visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FACMP1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(15),
                ],
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during today’s visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FFACTIME1",
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="care_visit_lost_income",
            field=intecomm_subject.models.fields.income_field.IncomeField(
                blank=True,
                metadata="FPAID1",
                null=True,
                verbose_name="How much would you have made in cash or in-kind for a day’s work?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="food_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FFOODCOST1",
                null=True,
                verbose_name="Thinking about yourself and anyone that accompanied you, how much did you have to pay for food, drink or other refreshments during your travel or during your visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_dm",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTDM1",
                verbose_name="How much was spent on Diabetes medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_hiv",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHIV1", verbose_name="How much was spent on HIV medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_htn",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTHTN1",
                verbose_name="How much was spent on Hypertension medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_other",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOSTOTHER1",
                verbose_name="How much was spent on OTHER medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FACTIVITY1",
                verbose_name="If you were not attending the visit today, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="travel_time",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FTRATIME1", verbose_name="How long did it take you to reach here?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="wait_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWAITIME1", verbose_name="How much time did you spend waiting?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="with_hcw_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FWORKTIME1",
                verbose_name="How much time did you spend during the consultation (i.e. time spent with the healthcareworker)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you here today",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="care_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFEECOST1",
                verbose_name="How much money did you spend on healthworker and consultation fees during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="care_visit_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTIME1",
                verbose_name="Roughly how much time did you spend during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="food_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTFOODCOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, did you have to pay for food, drink or other refreshments during your travel or during your last/most recent visit? (e.g. food, drink, etc.)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="ill_month",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                metadata="FILLMONTH1",
                verbose_name="Other than today’s visit, and thinking about the past 3 months, did you need to make any routine visits or were you ill or in need of healthcare at any point for HIV, Hypertension, Diabetes or anything related to you having these conditions?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_cost_tot",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTMEDCOST1", verbose_name="How much was spent on these medicines? "
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_not_collected_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("meds_at_home", "Already had the medicines at home"),
                    ("unavailable", "Medicines were not available"),
                    ("expensive", "Medicines were too expensive"),
                    ("home_remedies", "Home remedies are better"),
                    ("unimportant", "Did not think it was important to get these medicines"),
                    ("too_busy", "Did not have the time to collect or buy medicines"),
                    ("problematic", "Taking medicines caused problems"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDNO1",
                verbose_name="Why were these medicines not received/collected?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_prescribed",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FOUTMED1",
                verbose_name="Were you prescribed any medicines during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                blank=True,
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                ],
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Money received from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Money received from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="no_seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("not_necessary", "Did not think it was necessary "),
                    ("recovered", "Recovered before I could go "),
                    (
                        "home_remedy",
                        "Home remedy given by family member, relatives, neighbours ",
                    ),
                    ("too_expensive", "Too expensive "),
                    ("no_time", "Wanted to but could not find time"),
                    ("no_transport", "There was no one to take me"),
                    ("facility_too_far", "The health facility is too far/ not easy to reach "),
                    ("hcw_unavailable", "Health care practitioner mostly unavailable "),
                    ("med_problems", "Taking medicines caused problems"),
                    (
                        "hcw_confusing",
                        "Do not understand what the healthcare practitioner says ",
                    ),
                    ("hcw_incompetent", "Practitioner is not competent in their work "),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="If NO, STOP and SAVE form",
                max_length=25,
                metadata="FNOSEEK1",
                verbose_name="If no, why did you not make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you make the visit, seek advice or treatment (public facility, local pharmacy, traditional doctor etc)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("comm_health_centre", "Community health centre/health post"),
                    ("gov_dispensary", "Government dispensary"),
                    ("phc", "Primary health care center (PHC)"),
                    ("private_clinic", "Private clinic"),
                    ("ngo", "NGO clinic"),
                    ("public_hospital", "Public Hospital"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("hcw_home", "Any healthcare practitioner’s home"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKFAC1",
                verbose_name="If yes, where did you make the visit, seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTESTCOST1", verbose_name="How much did you spend on these tests?"
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_requested",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="for example, blood pressure, viral load, glucose etc.",
                max_length=25,
                metadata="FOUTTEST1",
                verbose_name="Did the healthcare worker request for any tests to be done during your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="travel_costs",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FOUTTRACOST1",
                verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="travel_duration",
            field=intecomm_subject.models.fields.duration_field.DurationAsStringField(
                metadata="FOUTTRATIME1", verbose_name="How long did it take you to get there?"
            ),
        ),
    ]
