# Generated by Django 4.2.11 on 2024-06-26 19:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0003_diagnoses_baseline"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="diagnoses",
            name="baseline",
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="baseline_182d",
            field=models.IntegerField(
                default=0,
                help_text="Number of diagnoses that qualify as baseline (182d before baseline)",
            ),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="baseline_6m",
            field=models.IntegerField(
                default=0,
                help_text="Number of diagnoses that qualify as baseline (6m before baseline)",
            ),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_baseline_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_baseline_value",
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_endline_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="diagnoses",
            name="vl_endline_value",
            field=models.IntegerField(null=True),
        ),
    ]
