# Generated by Django 4.2.10 on 2024-03-07 18:57

from django.db import migrations, models
import edc_model.models.fields.other_charfield
import edc_model_fields.fields.custom_django_fields


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("edc_he", "0007_remove_education_edc_he_educ_name_64c0c9_idx_and_more"),
        ("intecomm_subject", "0149_alter_bloodresultsfbc_consent_model_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekinga",
            name="money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FTODSOURCE",
                to="intecomm_lists.moneysources",
                verbose_name="Thinking about the expenses you have reported for today’s visit, what were the source(s) of payment for all these expenses?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FINSOURCE",
                related_name="%(app_label)s_inpatient_money_sources_related",
                related_query_name="%(app_label)s_inpatient_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="What were the source(s) of payment for all these expenses for your hospital stay?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_sources",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                help_text="Select up to three sources. If 'other', please specify.",
                metadata="FOUTSOURCE",
                related_name="%(app_label)s_money_sources_related",
                related_query_name="%(app_label)s_money_sources",
                to="intecomm_lists.moneysources",
                verbose_name="Thinking about the expenses you have reported in the past 3 months, and excluding today’s visit, what were the source(s) of payment for all these expenses?  ",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="complications",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If Yes, complete the 'Complications' CRF",
                max_length=15,
                verbose_name="Since last seen, has the patient had any complications",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_dm_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (DM)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_dm_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_hiv_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (HIV)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_hiv_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_htn_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...(HTN)",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_htn_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_other_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="rx_other_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="transport_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other reason', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_insurance",
            field=models.ManyToManyField(
                help_text="Not applicable if patient is head of household",
                related_name="+",
                to="edc_he.insurancetypes",
                verbose_name="Household head’s health insurance and 'club' status ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="complications",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="If Yes, complete the 'Complications' CRF",
                max_length=15,
                verbose_name="Since last seen, has the patient had any complications",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="patient_club",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="unknown",
                max_length=15,
                verbose_name="Does the patient belong to a 'club' that supports medicines purchase?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_dm_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (DM)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_dm_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_hiv_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ... (HIV)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_hiv_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_htn_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...(HTN)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_htn_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_other_paid_month_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="rx_other_paid_today_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other pay source', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomics",
            name="transport_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If 'other reason', please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedications",
            name="refill_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Diabetes.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Diabetes medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedications",
            name="refill_hiv",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for HIV infection.",
                max_length=25,
                verbose_name="Is the patient filling / refilling HIV medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedications",
            name="refill_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Hypertension.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Hypertension medications?",
            ),
        ),
        migrations.AlterField(
            model_name="medications",
            name="refill_dm",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Diabetes.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Diabetes medications?",
            ),
        ),
        migrations.AlterField(
            model_name="medications",
            name="refill_hiv",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for HIV infection.",
                max_length=25,
                verbose_name="Is the patient filling / refilling HIV medications?",
            ),
        ),
        migrations.AlterField(
            model_name="medications",
            name="refill_htn",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Select 'not applicable' if subject has not been diagnosed and prescribed medication for Hypertension.",
                max_length=25,
                verbose_name="Is the patient filling / refilling Hypertension medications?",
            ),
        ),
    ]
