# Generated by Django 4.2.11 on 2024-06-20 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="SubjectsTransferred",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField()),
                ("consented", models.DateField()),
                ("visit", models.DateField()),
                ("visit_code", models.CharField(max_length=100)),
                ("transferred", models.DateField(blank=True, null=True)),
                ("months", models.IntegerField(blank=True, null=True)),
                ("offstudy", models.DateField(blank=True, null=True)),
                ("offstudy_report", models.DateField(blank=True, null=True)),
            ],
            options={
                "verbose_name": "Subjects Transferred",
                "verbose_name_plural": "Subjects Transferred",
                "db_table": "subjects_transferred_view",
                "managed": False,
            },
        ),
    ]
