# Generated by Django 4.2.5 on 2023-10-05 23:38

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0120_remove_historicalnextappointment_info_source_new_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalnextappointment",
            old_name="info_source_new",
            new_name="info_source",
        ),
        migrations.RenameField(
            model_name="nextappointment",
            old_name="info_source_new",
            new_name="info_source",
        ),
    ]
