# Generated by Django 5.0.8 on 2024-08-26 15:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0013_auto_20240826_1807"),
    ]

    operations = [
        migrations.CreateModel(
            name="Eos",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("report_model", models.CharField(max_length=50)),
                ("subject_identifier", models.CharField(max_length=25)),
                ("created", models.DateTimeField()),
                ("visit_datetime", models.DateTimeField(blank=True, null=True)),
                (
                    "timepoint",
                    models.DecimalField(
                        blank=True, decimal_places=2, max_digits=10, null=True
                    ),
                ),
                ("visit_code", models.CharField(max_length=25, null=True)),
                ("visit_code_sequence", models.IntegerField(null=True)),
                ("offstudy_reason", models.CharField(blank=True, max_length=200, null=True)),
                ("offstudy_datetime", models.DateTimeField(blank=True, null=True)),
            ],
            options={
                "verbose_name": "End of study",
                "verbose_name_plural": "End of study",
                "db_table": "eos_view",
                "managed": False,
            },
        ),
    ]
