# Generated by Django 4.2.11 on 2024-07-29 21:40

from django.db import migrations
import django.db.models.manager
import edc_sites.managers


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0009_missingvldrawdates"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="missingvldrawdates",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
    ]
