# Generated by Django 4.2.1 on 2023-06-30 03:10

from django.db import migrations, models
import edc_utils


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0035_auto_20230630_0552"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="screening_identifier",
            field=models.CharField(
                db_index=True,
                default=edc_utils.get_uuid,
                help_text="Auto populated when screening form is complete",
                max_length=36,
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="subject_identifier",
            field=models.CharField(
                db_index=True,
                default=edc_utils.get_uuid,
                help_text="Auto populated when consent form is complete",
                max_length=36,
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="screening_identifier",
            field=models.CharField(
                default=edc_utils.get_uuid,
                help_text="Auto populated when screening form is complete",
                max_length=36,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="subject_identifier",
            field=models.CharField(
                default=edc_utils.get_uuid,
                help_text="Auto populated when consent form is complete",
                max_length=36,
                unique=True,
            ),
        ),
    ]
