# Generated by Django 4.2.10 on 2024-02-22 04:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0143_historicalcareseekingb_historicalcareseekinga_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekingb",
            old_name="meds_prescribed",
            new_name="med_prescribed",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="meds_prescribed",
            new_name="med_prescribed",
        ),
    ]
