# Generated by Django 4.2.11 on 2024-07-29 21:04

from django.db import migrations, models
import django.db.models.deletion
import edc_sites.managers
import edc_utils.date


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("intecomm_reports", "0008_alter_vl_options_alter_vlsummary_options_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="MissingVlDrawDates",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=25)),
                (
                    "report_model",
                    models.CharField(
                        default="intecomm_reports.missingvldrawdates", max_length=50
                    ),
                ),
                ("created", models.DateTimeField(default=edc_utils.date.get_utcnow)),
                ("baseline_date", models.DateField(null=True)),
                ("visit_date", models.DateField(null=True)),
                ("visit_code", models.FloatField(null=True)),
                ("vl", models.IntegerField(null=True)),
                (
                    "site",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT, to="sites.site"
                    ),
                ),
            ],
            options={
                "verbose_name": "Viral load: Missing draw date",
                "verbose_name_plural": "Viral load: Missing draw dates",
                "db_table": "intecomm_reports_missingvldrawdates",
            },
            managers=[
                ("on_site", edc_sites.managers.CurrentSiteManager()),
            ],
        ),
    ]
