# Generated by Django 4.2.3 on 2023-08-10 03:27

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0101_alter_healtheconomicspatient_pat_education_old_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_education_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_education_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="Highest level of education completed by the household head?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="Household head’s type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
    ]
