# Generated by Django 4.2.11 on 2024-04-22 16:44

import edc_model.models.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_subject", "0178_rename_travel_time_careseekinga_travel_duration_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalhtnreview",
            old_name="managed_by",
            new_name="managed_by_old",
        ),
        migrations.RenameField(
            model_name="htnreview",
            old_name="managed_by",
            new_name="managed_by_old",
        ),
    ]
