# Generated by Django 4.2.1 on 2023-05-24 22:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0049_alter_healtheconomicsincome_external_remittance_value_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.CharField(
                choices=[
                    ("baganda", "Baganda"),
                    ("banyakole", "Banyakole"),
                    ("basoga", "Basoga"),
                    ("bakiga", "Bakiga"),
                    ("iteso", "Iteso"),
                    ("langi", "Langi"),
                    ("acholi", "Acholi"),
                    ("bagisu", "Bagisu"),
                    ("lugbara", "Lugbara"),
                    ("banyoro", "Banyoro"),
                    ("bakhonzo", "Bakhonzo"),
                    ("batoro", "Batoro"),
                    ("alur", "Alur"),
                    ("OTHER", "Other, specify ..."),
                    ("msukuma", "Msukuma"),
                    ("mjita", "Mjita"),
                    ("mzinza", "Mzinza"),
                    ("myiramba", "Myiramba"),
                    ("mkara_mkerewe", "Mkara/Mkerewe"),
                    ("mhaya", "Mhaya"),
                    ("mjaluo", "Mjaluo"),
                    ("mkuria_mshashi", "Mkuria/Mshashi"),
                    ("mchaga", "Mchaga"),
                    ("mhindi", "Mhindi"),
                    ("mwarabu", "Mwarabu"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.CharField(
                choices=[
                    ("catholic", "Catholic"),
                    ("protestant", "Protestant"),
                    ("muslim", "Muslim"),
                    ("pentecostal", "Pentecostal"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                    ("muslim", "Muslim"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("tz_assemblies_of_god", "Tanzanian Assemblies of God"),
                    ("catholic", "Catholic"),
                    ("lutheran", "Lutheran"),
                    ("moravian", "Moravian"),
                    ("pentecostal", "Pentecostal"),
                    ("african_inland_church", "African Inland Church"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_ethnicity",
            field=models.CharField(
                choices=[
                    ("baganda", "Baganda"),
                    ("banyakole", "Banyakole"),
                    ("basoga", "Basoga"),
                    ("bakiga", "Bakiga"),
                    ("iteso", "Iteso"),
                    ("langi", "Langi"),
                    ("acholi", "Acholi"),
                    ("bagisu", "Bagisu"),
                    ("lugbara", "Lugbara"),
                    ("banyoro", "Banyoro"),
                    ("bakhonzo", "Bakhonzo"),
                    ("batoro", "Batoro"),
                    ("alur", "Alur"),
                    ("OTHER", "Other, specify ..."),
                    ("msukuma", "Msukuma"),
                    ("mjita", "Mjita"),
                    ("mzinza", "Mzinza"),
                    ("myiramba", "Myiramba"),
                    ("mkara_mkerewe", "Mkara/Mkerewe"),
                    ("mhaya", "Mhaya"),
                    ("mjaluo", "Mjaluo"),
                    ("mkuria_mshashi", "Mkuria/Mshashi"),
                    ("mchaga", "Mchaga"),
                    ("mhindi", "Mhindi"),
                    ("mwarabu", "Mwarabu"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_religion",
            field=models.CharField(
                choices=[
                    ("catholic", "Catholic"),
                    ("protestant", "Protestant"),
                    ("muslim", "Muslim"),
                    ("pentecostal", "Pentecostal"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                    ("muslim", "Muslim"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("tz_assemblies_of_god", "Tanzanian Assemblies of God"),
                    ("catholic", "Catholic"),
                    ("lutheran", "Lutheran"),
                    ("moravian", "Moravian"),
                    ("pentecostal", "Pentecostal"),
                    ("african_inland_church", "African Inland Church"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.CharField(
                choices=[
                    ("baganda", "Baganda"),
                    ("banyakole", "Banyakole"),
                    ("basoga", "Basoga"),
                    ("bakiga", "Bakiga"),
                    ("iteso", "Iteso"),
                    ("langi", "Langi"),
                    ("acholi", "Acholi"),
                    ("bagisu", "Bagisu"),
                    ("lugbara", "Lugbara"),
                    ("banyoro", "Banyoro"),
                    ("bakhonzo", "Bakhonzo"),
                    ("batoro", "Batoro"),
                    ("alur", "Alur"),
                    ("OTHER", "Other, specify ..."),
                    ("msukuma", "Msukuma"),
                    ("mjita", "Mjita"),
                    ("mzinza", "Mzinza"),
                    ("myiramba", "Myiramba"),
                    ("mkara_mkerewe", "Mkara/Mkerewe"),
                    ("mhaya", "Mhaya"),
                    ("mjaluo", "Mjaluo"),
                    ("mkuria_mshashi", "Mkuria/Mshashi"),
                    ("mchaga", "Mchaga"),
                    ("mhindi", "Mhindi"),
                    ("mwarabu", "Mwarabu"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.CharField(
                choices=[
                    ("catholic", "Catholic"),
                    ("protestant", "Protestant"),
                    ("muslim", "Muslim"),
                    ("pentecostal", "Pentecostal"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                    ("muslim", "Muslim"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("tz_assemblies_of_god", "Tanzanian Assemblies of God"),
                    ("catholic", "Catholic"),
                    ("lutheran", "Lutheran"),
                    ("moravian", "Moravian"),
                    ("pentecostal", "Pentecostal"),
                    ("african_inland_church", "African Inland Church"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_ethnicity",
            field=models.CharField(
                choices=[
                    ("baganda", "Baganda"),
                    ("banyakole", "Banyakole"),
                    ("basoga", "Basoga"),
                    ("bakiga", "Bakiga"),
                    ("iteso", "Iteso"),
                    ("langi", "Langi"),
                    ("acholi", "Acholi"),
                    ("bagisu", "Bagisu"),
                    ("lugbara", "Lugbara"),
                    ("banyoro", "Banyoro"),
                    ("bakhonzo", "Bakhonzo"),
                    ("batoro", "Batoro"),
                    ("alur", "Alur"),
                    ("OTHER", "Other, specify ..."),
                    ("msukuma", "Msukuma"),
                    ("mjita", "Mjita"),
                    ("mzinza", "Mzinza"),
                    ("myiramba", "Myiramba"),
                    ("mkara_mkerewe", "Mkara/Mkerewe"),
                    ("mhaya", "Mhaya"),
                    ("mjaluo", "Mjaluo"),
                    ("mkuria_mshashi", "Mkuria/Mshashi"),
                    ("mchaga", "Mchaga"),
                    ("mhindi", "Mhindi"),
                    ("mwarabu", "Mwarabu"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="What is the household head’s ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_religion",
            field=models.CharField(
                choices=[
                    ("catholic", "Catholic"),
                    ("protestant", "Protestant"),
                    ("muslim", "Muslim"),
                    ("pentecostal", "Pentecostal"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                    ("muslim", "Muslim"),
                    ("seventh_day_adventist", "Seventh day Adventist"),
                    ("tz_assemblies_of_god", "Tanzanian Assemblies of God"),
                    ("catholic", "Catholic"),
                    ("lutheran", "Lutheran"),
                    ("moravian", "Moravian"),
                    ("pentecostal", "Pentecostal"),
                    ("african_inland_church", "African Inland Church"),
                    ("no_religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
    ]
