# Generated by Django 4.2.10 on 2024-03-07 19:17

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("edc_he", "0007_remove_education_edc_he_educ_name_64c0c9_idx_and_more"),
        ("intecomm_subject", "0150_alter_careseekinga_money_sources_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="drugrefilldm",
            name="modifications_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodificationreasons",
                verbose_name="Why did the patient's previous prescription change?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefilldm",
            name="rx_modified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the patient's prescription changed at this visit compared with their prescription at the previous visit?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhiv",
            name="modifications_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodificationreasons",
                verbose_name="Why did the patient's previous prescription change?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhiv",
            name="rx_modified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the patient's prescription changed at this visit compared with their prescription at the previous visit?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhtn",
            name="modifications_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodificationreasons",
                verbose_name="Why did the patient's previous prescription change?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhtn",
            name="rx_modified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the patient's prescription changed at this visit compared with their prescription at the previous visit?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_status",
            field=models.CharField(
                choices=[
                    ("1", "Full time employed"),
                    ("2", "Regular part time employed "),
                    ("9", "Self employed "),
                    ("3", "Irregular/ occasional/ day worker employment"),
                    ("4", "Non-paid/ voluntary role "),
                    ("5", "Student"),
                    ("6", "Homemaker"),
                    ("7", "Unemployed (able to work)"),
                    ("8", "Unemployed (unable to work)"),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment",
                max_length=25,
                verbose_name="Household head's employment status",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.ForeignKey(
                help_text="Not applicable if patient is head of household",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.employmenttype",
                verbose_name="Household head's type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="Household head's type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.ForeignKey(
                help_text="Not applicable if patient is head of household",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.ethnicities",
                verbose_name="What is the household head's ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="What is the household head's ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_insurance",
            field=models.ManyToManyField(
                help_text="Not applicable if patient is head of household",
                related_name="+",
                to="edc_he.insurancetypes",
                verbose_name="Household head's health insurance and 'club' status ",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "Never Married (but not co-habiting)"),
                    ("2", "Co-habiting"),
                    ("3", "Currently Married"),
                    ("4", "Separated/Divorced"),
                    ("5", "Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household",
                max_length=25,
                verbose_name="Household head's marital status",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.ForeignKey(
                help_text="Not applicable if patient is head of household",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_he.religions",
                verbose_name="How would you describe the household head's religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="How would you describe the household head's religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_dependents",
            field=models.IntegerField(
                help_text="Insert '0' if no dependents other than the members in the household roster",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(15),
                ],
                verbose_name="Outside of this household, how many other people depend on this household's income?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household's financial situation compared with others in your community?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefilldm",
            name="rx_modified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the patient's prescription changed at this visit compared with their prescription at the previous visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhiv",
            name="rx_modified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the patient's prescription changed at this visit compared with their prescription at the previous visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldrugrefillhtn",
            name="rx_modified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=25,
                verbose_name="Was the patient's prescription changed at this visit compared with their prescription at the previous visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_status",
            field=models.CharField(
                choices=[
                    ("1", "Full time employed"),
                    ("2", "Regular part time employed "),
                    ("9", "Self employed "),
                    ("3", "Irregular/ occasional/ day worker employment"),
                    ("4", "Non-paid/ voluntary role "),
                    ("5", "Student"),
                    ("6", "Homemaker"),
                    ("7", "Unemployed (able to work)"),
                    ("8", "Unemployed (unable to work)"),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household. If the household head has more than one job, think about their MAIN source of employment",
                max_length=25,
                verbose_name="Household head's employment status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="Not applicable if patient is head of household",
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.employmenttype",
                verbose_name="Household head's type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_employment_type_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="Household head's type of employment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="Not applicable if patient is head of household",
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.ethnicities",
                verbose_name="What is the household head's ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_ethnicity_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="What is the household head's ethnic background?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_marital_status",
            field=models.CharField(
                choices=[
                    ("1", "Never Married (but not co-habiting)"),
                    ("2", "Co-habiting"),
                    ("3", "Currently Married"),
                    ("4", "Separated/Divorced"),
                    ("5", "Widowed"),
                    ("OTHER", "Other, specify ..."),
                    ("dont_know", "Don't know"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                help_text="Not applicable if patient is head of household",
                max_length=25,
                verbose_name="Household head's marital status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="Not applicable if patient is head of household",
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.religions",
                verbose_name="How would you describe the household head's religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                default="QUESTION_RETIRED",
                editable=False,
                max_length=25,
                verbose_name="How would you describe the household head's religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_dependents",
            field=models.IntegerField(
                help_text="Insert '0' if no dependents other than the members in the household roster",
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(15),
                ],
                verbose_name="Outside of this household, how many other people depend on this household's income?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don't want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household's financial situation compared with others in your community?",
            ),
        ),
    ]
