from .community_care_location_admin import CommunityCareLocationAdmin
from .patient_followup_call_admin import PatientFollowupCallAdmin
from .patient_group_admin import PatientGroupAdmin
from .patient_group_appointment_admin import PatientGroupAppointmentAdmin
from .patient_group_meeting_admin import PatientGroupMeetingAdmin
