# Generated by Django 4.2.7 on 2023-11-14 18:51

from django.db import migrations
import edc_visit_tracking.managers
import intecomm_subject.models.subject_visit


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0122_remove_historicalnextappointment_info_source_old_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectvisit",
            managers=[
                ("objects", edc_visit_tracking.managers.VisitModelManager()),
                ("on_site", intecomm_subject.models.subject_visit.CurrentSiteManager()),
            ],
        ),
    ]
