# Generated by Django 4.2.9 on 2024-02-01 14:14

import django.core.validators
from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0139_alter_bloodresultsins_fasting_duration_minutes_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalhivreview",
            name="drawn_date",
            field=models.DateField(
                blank=True,
                help_text="If exact date not known, please estimate",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date specimen drawn",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="has_vl",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Is the patient's most recent viral load result available?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="vl",
            field=models.IntegerField(
                blank=True,
                help_text="copies/mL",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="Most recent viral load",
            ),
        ),
        migrations.AddField(
            model_name="historicalhivreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("=", "="), (">", ">"), ("<", "<"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="drawn_date",
            field=models.DateField(
                blank=True,
                help_text="If exact date not known, please estimate",
                null=True,
                validators=[edc_model.validators.date.date_not_future],
                verbose_name="Date specimen drawn",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="has_vl",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("PENDING", "Pending"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="Is the patient's most recent viral load result available?",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="vl",
            field=models.IntegerField(
                blank=True,
                help_text="copies/mL",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="Most recent viral load",
            ),
        ),
        migrations.AddField(
            model_name="hivreview",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("=", "="), (">", ">"), ("<", "<"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=10,
                null=True,
            ),
        ),
    ]
