# Generated by Django 4.2.1 on 2023-07-05 03:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0043_auto_20230705_0529"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="This question is asked to confirm you are logged in to the correct site.",
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="intecomm_screening.site",
                verbose_name="Which site is this?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="patient_log_identifier",
            field=models.CharField(
                db_index=True, max_length=50, verbose_name="Patient log identifier"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="site",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="intecomm_screening.site",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="site",
            field=models.ForeignKey(
                help_text="This question is asked to confirm you are logged in to the correct site.",
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_screening.site",
                verbose_name="Which site is this?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="patient_log_identifier",
            field=models.CharField(
                max_length=50, unique=True, verbose_name="Patient log identifier"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="site",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="intecomm_screening.site",
            ),
        ),
    ]
