# Generated by Django 4.2.7 on 2023-11-29 20:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0126_feat_683_land_area_units"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="appt_date",
            field=models.DateField(
                blank=True,
                help_text="Should fall on an Integrated clinic day",
                null=True,
                verbose_name="Next scheduled routine/facility appointment",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="appt_date",
            field=models.DateField(
                blank=True,
                help_text="Should fall on an Integrated clinic day",
                null=True,
                verbose_name="Next scheduled routine/facility appointment",
            ),
        ),
    ]
