{% extends "edc_model_admin/admin/change_list.html" %}
{% load i18n admin_urls static admin_list edc_admin_modify protocol_dashboard_extras %}

{% block object-tools-items %}
  {% intecomm_changelist_topbar changelist_top_bar_selected %}
{% endblock %}
