# Generated by Django 4.2.11 on 2024-07-02 04:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0006_auto_20240702_0406"),
    ]

    operations = []
