# Generated by Django 4.1.7 on 2023-03-31 02:19

from django.db import migrations, models
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0004_rxmodificationreasons_rxmodifications_and_more"),
        ("intecomm_subject", "0015_alter_bloodresultsfbc_results_abnormal_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="clinicalreview",
            name="reason_other",
        ),
        migrations.RemoveField(
            model_name="historicalclinicalreview",
            name="reason_other",
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="As of today, was the patient <u>newly</u> diagnosed with diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="dm_reason_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="hiv_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="As of today, was the patient <u>newly</u> diagnosed with HIV infection?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="hiv_reason_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="As of today, was the patient <u>newly</u> diagnosed with hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreview",
            name="htn_reason_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefilldm",
            name="modifications",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodifications",
                verbose_name="Which changes occurred?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefilldm",
            name="modifications_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodificationreasons",
                verbose_name="Why did the patient’s previous prescription change?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhiv",
            name="modifications",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodifications",
                verbose_name="Which changes occurred?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhiv",
            name="modifications_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodificationreasons",
                verbose_name="Why did the patient’s previous prescription change?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhtn",
            name="modifications",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodifications",
                verbose_name="Which changes occurred?",
            ),
        ),
        migrations.AlterField(
            model_name="drugrefillhtn",
            name="modifications_reason",
            field=models.ManyToManyField(
                blank=True,
                to="intecomm_lists.rxmodificationreasons",
                verbose_name="Why did the patient’s previous prescription change?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="As of today, was the patient <u>newly</u> diagnosed with diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="dm_reason_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="hiv_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="As of today, was the patient <u>newly</u> diagnosed with HIV infection?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="hiv_reason_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=15,
                verbose_name="As of today, was the patient <u>newly</u> diagnosed with hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreview",
            name="htn_reason_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]
