# Generated by Django 4.2.10 on 2024-02-22 05:27

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "intecomm_subject",
            "0145_rename_facility_visit_alt_careseekinga_missed_activities_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekingb",
            old_name="seek_inpatient_visits",
            new_name="inpatient_days",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="seek_outpatient_visits",
            new_name="outpatient_visits",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="seek_inpatient_visits",
            new_name="inpatient_days",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="seek_outpatient_visits",
            new_name="outpatient_visits",
        ),
    ]
