from .assets_admin import HealthEconomicsAssetsAdmin
from .careseeking_a_admin import CareseekingAAdmin
from .careseeking_b_admin import CareseekingBAdmin
from .household_head_admin import HealthEconomicsHouseholdHeadAdmin
from .income_admin import HealthEconomicsIncomeAdmin
from .patient_admin import HealthEconomicsPatientAdmin
from .property_admin import HealthEconomicsPropertyAdmin
