# Generated by Django 4.1.2 on 2022-11-26 03:40

from django.db import migrations
import edc_sites.models
import intecomm_group.models.patient_group


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0009_auto_20221126_0358"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="patientgroup",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", intecomm_group.models.patient_group.PatientGroupManager()),
            ],
        ),
    ]
