{% load i18n %}
<H5><B><span style="color:orange">{% trans "Interviewer to read" %}</span></B></H5>
<p style="background-color: yellow; padding: 10px;">{% trans "Thank you very much for all your responses about today’s visit. Now, I would like to ask you similar questions about any other health visits you may have had in the past 3 months. " %}
  <BR>
  <BR>{% trans "This is to help us understand if you saw health providers of any type in the past three months, how many visits you might have made and the costs to you and your household from those visits." %}
  <BR>
  <BR>{% trans "When thinking and responding about any health providers you might have visited in the past three months, <B>PLEASE DO NOT INCLUDE TODAY’S VISIT IN YOUR RESPONSES</B>." %}

</p>
