# Generated by Django 4.2.11 on 2024-06-21 13:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_reports", "0002_diagnoses"),
    ]

    operations = [
        migrations.AddField(
            model_name="diagnoses",
            name="baseline",
            field=models.IntegerField(
                default=0,
                help_text="Number of diagnoses that qualify as baseline (182 days before baseline)",
            ),
        ),
    ]
