# Generated by Django 4.1.2 on 2022-11-20 21:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0002_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientgroup",
            name="group_identifier",
            field=models.CharField(max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name="patientgroup",
            name="group_identifier",
            field=models.CharField(max_length=36, null=True),
        ),
    ]
