# Generated by Django 4.2.11 on 2024-04-22 16:45

from django.db import migrations, models
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        (
            "intecomm_subject",
            "0179_rename_managed_by_historicalhtnreview_managed_by_old_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalhtnreview",
            name="managed_by_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="htnreview",
            name="managed_by",
            field=models.ManyToManyField(
                to="intecomm_lists.htnmanagement",
                verbose_name="How will the patient's hypertension be managed going forward?",
            ),
        ),
        migrations.AddField(
            model_name="htnreview",
            name="managed_by_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]
