# Generated by Django 4.1.7 on 2023-04-20 01:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0033_clinicalreviewbaseline_dm_dx_at_screening_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="clinicalreviewbaseline",
            name="protocol_incident",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Do any of the above diagnosis differ from those reported at screening?",
            ),
        ),
        migrations.AddField(
            model_name="historicalclinicalreviewbaseline",
            name="protocol_incident",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                max_length=15,
                verbose_name="Do any of the above diagnosis differ from those reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with DIABETES?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="dm_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of DIABETES reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="hiv_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HIV reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with HYPERTENSION?",
            ),
        ),
        migrations.AlterField(
            model_name="clinicalreviewbaseline",
            name="htn_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HYPERTENSION reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with DIABETES?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="dm_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of DIABETES reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="hiv_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HIV reported at screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_dx",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Has the patient ever been diagnosed with HYPERTENSION?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalclinicalreviewbaseline",
            name="htn_dx_at_screening",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                verbose_name="Was a diagnosis of HYPERTENSION reported at screening?",
            ),
        ),
    ]
