# Generated by Django 5.0.4 on 2024-04-10 21:30

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0157_alter_careseekingb_med_conditions_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="med_collected",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDCOLL1",
                verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="med_cost_tot",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTMEDCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent on these medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTTESTCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much did you spend on these tests?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_collected",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                metadata="FOUTMEDCOLL1",
                verbose_name="Did you receive/collect these medicines (whether paid or received for free)?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="med_cost_tot",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTMEDCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much was spent on these medicines? ",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_cost",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                help_text="in local currency",
                metadata="FOUTTESTCOST1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(9999999),
                ],
                verbose_name="How much did you spend on these tests?",
            ),
        ),
    ]
